@@ -264,6 +264,8 @@ class Api {
 
     DHCP_RESET = { path: 'dhcp/reset', method: 'POST' };
 
+    DHCP_LEASES_RESET = { path: 'dhcp/reset_leases', method: 'POST' };
+
     getDhcpStatus() {
         const { path, method } = this.DHCP_STATUS;
         return this.makeRequest(path, method);
@@ -315,6 +317,11 @@ class Api {
         return this.makeRequest(path, method);
     }
 
+    resetDhcpLeases() {
+        const { path, method } = this.DHCP_LEASES_RESET;
+        return this.makeRequest(path, method);
+    }
+
     // Installation
     INSTALL_GET_ADDRESSES = { path: 'install/get_addresses', method: 'GET' };
 
