@@ -1,19 +1,14 @@
+//go:build windows
 // +build windows
 
 package aghos
 
 import (
-	"fmt"
-	"syscall"
-
 	"golang.org/x/sys/windows"
 )
 
-func canBindPrivilegedPorts() (can bool, err error) {
-	return HaveAdminRights()
-}
-
-func setRlimit(val uint) {
+func setRlimit(val uint64) (err error) {
+	return Unsupported("setrlimit")
 }
 
 func haveAdminRights() (bool, error) {
@@ -37,10 +32,6 @@ func haveAdminRights() (bool, error) {
 	return true, nil
 }
 
-func sendProcessSignal(pid int, sig syscall.Signal) error {
-	return fmt.Errorf("not supported on Windows")
-}
-
 func isOpenWrt() (ok bool) {
 	return false
 }
